Traitlets config API reference
==============================

.. currentmodule:: traitlets.config

.. autoclass:: Configurable
    :members:

.. autoclass:: SingletonConfigurable
    :members:

.. autoclass:: Application
    :members:

.. autoclass:: Config
    :members:


.. autoclass:: traitlets.config.loader.LazyConfigValue
    :members:

.. autoclass:: traitlets.config.loader.KVArgParseConfigLoader
    :members: __init__, load_config
